tisdb package — tisdb 0.0.1.dev0 documentation

# tisdb package

## Subpackages

- tisdb.model package
  - Subpackages
    - tisdb.model.mysql package
      - Module contents
  - Module contents

## Submodules

- tisdb.api module
- tisdb.client module
- tisdb.config module
- tisdb.errors module
- tisdb.types module

## Module contents

### TiSDB

TiSDB is a relational DB based tsdb library for python tsdb project development that inherited and learned from TIDB and OpenTSDB.

copyright

  Copyright (c) 2021 by the TiSDB team.

license

  BSD, see LICENSE.rst for details.